@@ -219,7 +219,7 @@ class AugmentationDataLoaderXY(DataLoader2):
     ) -> None:
         reading_service = None
         if threads is not None:
-            reading_service = MultiProcessingReadingService(num_workers=threads, pin_memory=pinMemory)
+            reading_service = MultiProcessingReadingService(num_workers=threads)
         super().__init__(datapipe, datapipe_adapter_fn, reading_service)
 
     def __len__(self):
