@@ -44,8 +44,7 @@ class SignalPreprocessing:
                         options = {}
                         if isinstance(processStep, dict):
                             name = processStep["name"]
-                            del processStep["name"]
-                            options = processStep
+                            options = {key: value for key, value in processStep if key != "name"}
                             processStep = name
                         self.step(processStep, signal, psgSignal, **options)
                 elif signalType is not None:
